@@ -5,7 +5,7 @@ use utf8;
 use Furl::HTTP;
 use Furl::Response;
 use Carp ();
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 use 5.008001;
 
@@ -26,7 +26,7 @@ sub new {
 }
 
 sub agent {
-    @_ == 2 ? $$_[0]->agent($_[1]) : $$_[0]->agent;
+    @_ == 2 ? ${$_[0]}->agent($_[1]) : ${$_[0]}->agent;
 }
 
 sub env_proxy {
